"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const typeorm_1 = require("typeorm");
const path_1 = __importDefault(require("path"));
const logger_1 = require("logger");
const paths_1 = __importDefault(require("./constants/paths"));
class DatabaseConnector {
    constructor(config) {
        this.config = config;
        this.modelsFolder = paths_1.default.ENTITIES;
    }
    async loadModels() {
        const modelFiles = fs_1.default
            .readdirSync(this.modelsFolder)
            .map(async (modelFile) => Promise.resolve().then(() => __importStar(require(`${this.modelsFolder}/${modelFile}`))));
        logger_1.logger.log(modelFiles);
        const loadedEntities = await Promise.all(modelFiles);
        return loadedEntities.reduce((prev, next) => {
            const name = Object.keys(next)[0];
            const value = Object.values(next)[0];
            return Object.assign(Object.assign({}, prev), { [name]: typeorm_1.getRepository(value) });
        }, {});
    }
    async createConnection() {
        const entitiesResolver = path_1.default.join(this.modelsFolder, '*.ts');
        const { db: { database, host, password, port, username, ssl, }, } = this.config;
        return typeorm_1.createConnection({
            type: 'postgres',
            host,
            port,
            username,
            password,
            database,
            ssl,
            entities: [
                path_1.default.normalize(entitiesResolver),
            ],
        });
    }
    async getDbConnector() {
        const connection = await this.createConnection();
        const repositories = await this.loadModels();
        return {
            connection,
            repositories,
        };
    }
}
exports.default = DatabaseConnector;
//# sourceMappingURL=DatabaseLoader.js.map